Internal function to generate random numbers following over-dispersed Poisson distribution based on simple cheat of using a standard negative binomial, but choosing the scale parameter to give the desired mean vs variance ratio at the given value of the mean. Taken from: https://stat.ethz.ch/pipermail/r-help/2002-June/022425.html
rpoisod(n, lambda, d = 1)a vector with the simulated sample.
integer. Number of observations.
numeric. Mean.
numeric. Dispersion parameter.